QsUploadFile class

待上传文件

Constructors

QsUploadFile({required String fieldName, required String filePath, String? fileName})
const

Properties

fieldName String
Property 表单字段名
final
fileName String?
上传文件名,未设置时使用本地文件名
final
filePath String
本地文件路径
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited